@@ -199,7 +199,7 @@ class BookData:
             aud_authors_arr = []
             for author in aud_authors_json:
                 # Use ASIN for author only if available
-                if author['asin']:
+                if 'asin' in author:
                     # from array of dicts, get author name
                     aud_authors_arr.append(
                         {
@@ -294,3 +294,17 @@ class BookData:
 
         # return all data
         return metadata_dict
+
+    def check_asin_sku(self):
+        # Login or register as needed
+        self.auth.handle_auth()
+        aud_json = self.auth.client.get(
+            f"catalog/products/{self.asin}",
+            params={
+                "response_groups": "sku",
+                "asins": self.asin
+            }
+        )
+        if 'sku' in aud_json['product']:
+            return True
+        return None
